function F = findu(u_SS,chi,lambdaP,rhotottarget)

% u_SS = u_SS*(u_SS>0)+1e-7*(u_SS<=0) %%%%%% not sure whether this needs to be augmented
% u_SS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% TARGETS
firmexotarget     = 0.25;                             % ss target: JD due to firm exit
feregrateP        = 0.69;                             % ss target: share of per-capita gdp spent on regulaiton
fetechtarget      = 0.65;                             % ss target: R&D expenditure at firm level;
% markuptarget      = 1.1;                              % ss target: markup


% labor market parameters
etaP              = 0.6;                              % worker's bargaining power
epsP              = etaP;                             % matching function (elasticity of UNEMPLOYMENT);


%% preferences %%%%%%%%%
betaP             = 0.989;                            % discount rate
gammaP            = 1;                                % intertemporal elasticity of substitution

%% entry parameters
NbarP             = 100;                              % maximum number of potential varieties

% capital
alphaP            = 0.33;                             % capital share in the production function
adjIP             = 1.5;                              % size of investment adjustment costs
shapeP            = 1;                                % exponent of idiosyncratic productivity shock in individual production function 
exponenpfP        = shapeP/(1 - alphaP);              % exponent of zc in marhinal producuct of marginal worker
deltakP           = 0.025;                            % capital depreciation


% aggregate and idiosyncratic shocks
meanziP           = 0;                                % mean of lognormal distribution
stdziP            = 0.147;                            % std deviation of idiosyncratic shocks
stdzP             = 0.0099;                           % standard deviation of technology shock;
rhozP             = 0.983;                            % persistence of aggregate productivity shocks

load options
if momentsI==0
    rhozP = 0.9;
end


piP               = pi;                               % pi greek
    

deltafP              = firmexotarget*rhotottarget/(1 + firmexotarget*rhotottarget);

% changes for optimal model
exoseptarget         = lambdaP/((1-deltafP)*rhotottarget); 
hpP                  = 0.381670613960743; 
chiP                 = 0.430141765054595;
vcP                  = 0.127686748752117;
sigmaMuP             = 3.128612981374242;      
fcP                  = 0.115517477082678;
% u_SS                 = 0.094700000000000;


options = optimset('Display','off','MaxIter', 5000,'MaxFunEvals',5000,'TolFun', 1.0000e-14,'TolX', 1.0000e-14);
x0 = [1.870180825650245,20.335391040588610,1.637009599386109,0.627036383400334,0.6,3.196304579548057,1.065279503308597]; 

lb = [0,0,0,0,0,0,-0];
ub = [5,50,5,5,1,100,5];


[steadySol,fval] = lsqnonlin(@(x) calibration_solver(x,u_SS,rhotottarget,lambdaP,chi),x0,lb,ub,options);
fval

c_SS             = steadySol(1);
k_SS             = steadySol(2);
w_SS             = steadySol(3);
zc_SS            = steadySol(4);
q_SS             = steadySol(5);
N_SS             = steadySol(6);
ubP              = steadySol(7);



if max(abs(fval)) > 1e-10
    display('Inaccurate initial steady state')
    disp([' fval = ' num2str(max(abs(fval)),'%.4f') ]);
    keyboard
end

if min(steadySol) < 0
    display('Zero or negative initial steady-state values')    
    keyboard
end


                    
elasticity_SS       =(1 + sigmaMuP*N_SS);
markup_SS           = elasticity_SS/(elasticity_SS - 1);
rpD_SS              =(exp(-0.5*(NbarP-N_SS)/(sigmaMuP*NbarP*N_SS)));
% ubP                 = rrRateP*w_SS/rpD_SS; 


z_SS                = 1;
mc_SS               = rpD_SS/markup_SS;
Ne_SS               = (deltafP/(1-deltafP))*N_SS;
rho_SS              = cdf('lognormal', zc_SS , meanziP , stdziP);
zavInt_SS           = (-1/2*piP^(1/2)*exp(1/2*(2*meanziP+stdziP^2*shapeP)*shapeP/(1-2*alphaP+alphaP^2))*(erf(1/2*2^(1/2)/stdziP*(-log(zc_SS)+log(zc_SS)*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/(-1+alphaP))-erf(1/2*2^(1/2)*(-10000000000+10000000000*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/stdziP/(-1+alphaP)))*exp(-shapeP*meanziP*alphaP/(-1+alphaP)^2)/piP^(1/2))/(1-rho_SS);
zav_SS              = zavInt_SS^(1/exponenpfP);
l_SS                = 1 - u_SS;
m_SS                = (l_SS - (1-lambdaP)*(1-deltafP)*(1-rho_SS)*l_SS)/((1-lambdaP)*(1-deltafP)*(1-rho_SS));
v_SS                = m_SS/q_SS;
s_SS                = m_SS/u_SS;
yn_SS               = z_SS*(zav_SS^shapeP)*(k_SS^alphaP)*(l_SS^(1-alphaP));
mpl_SS              = (1 - alphaP)*mc_SS*yn_SS/l_SS;
mplzc_SS            = mpl_SS*((zc_SS/zav_SS)^exponenpfP);
wzc_SS              = w_SS - etaP*(mpl_SS - mplzc_SS); 
phi_SS              = mpl_SS + vcP/q_SS - (etaP*(mpl_SS + vcP*(s_SS/q_SS)) + (1-etaP)*(ubP + hpP) + (etaP*(1 - (1-lambdaP)*(1-deltafP)*(1-s_SS)*betaP)*fcP));
mpk_SS              = alphaP*mc_SS*yn_SS/k_SS;
ik_SS               = deltakP*k_SS;                     
kfirm_SS            = k_SS/N_SS;
lfirm_SS            = l_SS/N_SS;
cm_SS               = c_SS - hpP*(1-l_SS);

fetechP              = fetechtarget*yn_SS;
fr_SS                = feregrateP*yn_SS;

fe_SS                = fetechP + fr_SS;
y_SS                 = Ne_SS*fe_SS + cm_SS + ik_SS + vcP*v_SS + rho_SS*l_SS*fcP/(1-rho_SS);
yfirm_SS             = (1/rpD_SS)*y_SS/N_SS;
vfirm_SS             = (v_SS - Ne_SS*lfirm_SS/q_SS)/(N_SS + Ne_SS);
d_SS                 = rpD_SS*yfirm_SS - mpk_SS*kfirm_SS - vcP*vfirm_SS - rho_SS*lfirm_SS*fcP/(1-rho_SS)  - lfirm_SS*w_SS;
e_SS                 = fe_SS + vcP*(lfirm_SS/q_SS + vfirm_SS);
firing_SS            = etaP*(1 - (1-lambdaP)*(1-deltafP)*(1-s_SS)*betaP)*fcP;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
surplusF_SS          = phi_SS + fcP;
surplusW_SS          = (etaP/(1-etaP))*surplusF_SS;
oo_SS                = hpP + ubP + s_SS*(1-lambdaP)*(1-deltafP)*betaP*(1-rho_SS)*surplusW_SS;
ub_SS                = ubP;
fc_SS                = fcP;
rk_SS                = mpk_SS;
multR_SS             = 1;
adjI_SS              = 0;

rhotot_SS            = (1 - (1-lambdaP)*(1-deltafP)*(1-rho_SS))/((1-lambdaP)*(1-deltafP)*(1-rho_SS));
itot_SS              = ik_SS + Ne_SS*e_SS;
gdpIncome_SS         = w_SS*l_SS + rk_SS*k_SS + N_SS*d_SS;
gdpExpen_SS          = cm_SS + ik_SS;
phizc_SS             = mplzc_SS - wzc_SS + (1-lambdaP)*(1-deltafP)*(betaP)*( (1-rho_SS)*phi_SS - rho_SS*fc_SS ); 
surplusWzc_SS        = wzc_SS - oo_SS + (1-lambdaP)*(1-deltafP)*(betaP)*(1-rho_SS)*surplusW_SS; 
surplusFzc_SS        = phizc_SS + fc_SS;


%New variables
rrRateP_SS = ubP/w_SS*rpD_SS;
Util_SS = log(c_SS) - chi*(1-u_SS)^2/2;
Welf_SS    = (1/(1-betaP))*Util_SS;

YY         =  [ - yn_SS         + yfirm_SS*N_SS;
                - vcP           + q_SS*( - mpl_SS*((zc_SS/zav_SS)^exponenpfP) + wzc_SS - fcP);
                - vcP/q_SS      + betaP*(1-lambdaP)*(1-deltafP)*( (1 - rho_SS)*phi_SS - rho_SS*fcP);                  
                - 1             + betaP*(mpk_SS  + 1 - deltakP);
                - w_SS          + etaP*(mpl_SS + vcP*(s_SS/q_SS)) + (1-etaP)*(ubP + hpP) + firing_SS; 
                - m_SS          + (chiP*(v_SS^(1-epsP))*(u_SS^(epsP)));
                - e_SS          + (((1-deltafP)*betaP)/(1 - (1-deltafP)*betaP))*d_SS;];

F = -Welf_SS;
